#
# spec file for package python-aexpect
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global         pkgname aexpect
Name:           python-%{pkgname}
Version:        1.7.0
Release:        2.2
Summary:        Python library to control interactive applications
License:        GPL-2.0-only
URL:            http://avocado-framework.readthedocs.org/
Source:         https://github.com/avocado-framework/aexpect/archive/%{version}.tar.gz#/%{pkgname}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM Based on gh#avocado-framework/aexpect#128
Patch0:         drop-use-of-pipes.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Aexpect is a Python library used to control interactive applications, very
similar to pexpect. It can be used to control applications such as ssh, scp
sftp, telnet, among others.

%prep
%autosetup -p1 -n %{pkgname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/aexpect_helper
%fdupes %{buildroot}

%check
export PATH=$PATH:%{buildroot}%{_bindir}
%pytest -k 'not pass_fds_spawn and not share_remote_objects'

%post
%python_install_alternative aexpect_helper

%postun
%python_uninstall_alternative aexpect_helper

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/aexpect_helper
%{python_sitelib}/aexpect
%{python_sitelib}/aexpect-%{version}.dist-info

%changelog
* Tue Dec 10 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch drop-use-of-pipes.patch:
  * Use shlex, not pipes module.
- Switch to pyproject macros.
* Fri Oct 20 2023 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 1.7.0
  * rss_client: fix syntax error
  * client: Make sure aexpect_helper file descriptors are closed
  * astring: Add bracketed paste console codes
  * Simpler ns daemon and current linter fixes
  * Drop unexpected and unwanted re.sub string postprocessing
  * Remove six dependency
  * Fix remote_door set_subcontrol_* handling of no matches
  * Add session ops utility with some facilitator functions (v2)
  * Fill setup.py license and metadata
  * Allow to calculate hashes on parts of files
  * Provide the session prefix when logging sent commands
  * Implement a reusable subcommand output and status processing routine
  * Add a generic ops module for windows platforms
  * Add remote linux glob behavior to expand paths from patterns
  * Avoid printing line when output_func not set
- drop helper-version-in-cmdline.patch
- drop 0001-Remove-six-dependency.patch
* Wed Oct 19 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add 0001-Remove-six-dependency.patch upstream patch to remove python-six
  dependency gh#avocado-framework/aexpect#102
- More specific python_sitelib in files
- Use autosetup instead of setup and autopatch
* Mon Jan 10 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.6.4:
  * No changelog available.
- Refresh helper-version-in-cmdline.patch.
- Add missing {Build,}Requires on six.
* Mon Aug 16 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.6.2:
  * No changelog available
- Add patch helper-version-in-cmdline.patch:
  * Always call the correct version of the helper script.
- Drop {Build,}Requires on Python 3 subprocess backport module.
- Switch to pytest, and skip two truculent tests
* Fri Jul 27 2018 mpluskal@suse.com
- Update to version 1.5.1:
  * No changelog available
- Correct dependencies
- Run tests
* Thu Oct 12 2017 jengelh@inai.de
- Update package descriptions.
* Thu Oct  5 2017 mpluskal@suse.com
- Convert to singlespec
* Fri Jul  7 2017 brogers@suse.com
- Initial check-in
